#!/bin/sh

if [ -n "$PLESK_INSTALLER_DEBUG" -o -n "$PLESK_INSTALLER_VERBOSE" ]; then
	set -x;
fi

prefix=""
root_d="/usr/local/psa"
install_d="$root_d/admin/sbin"
tmpdir="$root_d/var"

prog="`basename $0`"
mu="`echo $prog | awk -F '-' '{print $1}'`"

detect_mta()
{
	local mta_name str

	if which rpm >/dev/null 2>&1; then
		str="`rpm -qa|grep plesk-mail-[pq]c-driver`"
	fi
	if which dpkg >/dev/null 2>&1; then
		str="`dpkg --get-selections plesk-mail-[pq]c-driver | awk '{if ($2 == \"install\") {print $1}}'`"
	fi

	case "$str" in
		plesk-mail-pc-driver*) mta_name="postfix";;
		plesk-mail-qc-driver*) mta_name="qmail" ;;
		*)
			echo "WARNING!!! Unable to detect your MTA service driver. Microupdate will not be installed."
			return 1
		;;
	esac

	echo "$mta_name"
	return 0
}

prefix="`detect_mta`" || exit 0

restorecmd=":"
which restorecon > /dev/null
if [ $? = 0 ]; then
        restorecmd="restorecon"
fi

# replace mailmng
sum_new="`md5sum $tmpdir/listmng-${prefix} | cut -d\  -f 1`"
sum_old="`md5sum $install_d/listmng | cut -d\  -f 1`"
if [ "$sum_old" != "$sum_new" ]; then
	cp -f $tmpdir/listmng-${prefix} $install_d/listmng
	# change permissions
	chown root:root $install_d/listmng
	chmod 0750 $install_d/listmng

	$restorecmd $install_d/listmng
fi

exit 0
